```
Usage: vcd vapp network services [OPTIONS] COMMAND [ARGS]...

  Configure services of vapp network.

Options:
  -h, --help  Show this message and exit.

Commands:
  dhcp      manage DHCP service of vapp network
  firewall  manage firewall service of vapp network

```
